(faq)=

# Frequently Asked Questions (FAQs)

## How do I annotate data for use with `vak`?

There are several ways to annotate data.
When we began developing `vak`, 
we were working with two MATLAB-based GUIs 
for annotation. 
The first was originally developed
by Evren Tumer in the Brainard lab,
and we are happy to share it upon request
(please send an email to nicholdav at gmail dot com). 
The second was developed by Yarden Cohen 
and can be found here:
<https://github.com/yardencsGitHub/BirdSongBout/tree/master/helpers/GUI>.
Additionally, we are adding support for annotation tools
that are commonly used in the bioacoustics and linguistics 
communities: 
[Audacity](https://www.fon.hum.uva.nl/praat/manual/Intro_7__Annotation.html) 
and 
[Praat](https://www.fon.hum.uva.nl/praat/manual/Intro_7__Annotation.html).
Support for both is a work in progress, 
but we would be very happy to collaborate 
with anyone using these applications,
since they are widely known and 
years of development work have gone into them.

We are well aware that both applications
(as great as they are)
are less than perfect for researchers 
working with animal behavior and bioacoustics data.
We are developing an open-source application 
for annotation and analysis,
tailored to the needs of this research community.
Please feel free to contact the lead developer directly 
if you would like try out early versions of this application 
and guide its development with your feedback:
nicholdav at gmail dot com.

## How do I use a custom annotation format?

Please see this how-to: {ref}`howto-user-annot`

## How do I use spectrograms that I generate with my own code?
Please see this how-to: {ref}`howto-user-annot`.
